DefaultConfig

Struct DefaultConfig 

pub struct DefaultConfig;
The upstream template configuration (examples/template_configuration/FreeRTOSConfig.h, V11.3.1), value for value: 100 Hz, 5 priorities, 128-word stacks, 16-character names, 32-bit ticks, preemption on, time slicing off, the timer task at the highest priority with a 10-deep queue, stack overflow method 2, a 4 KiB heap.